/*
 * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
 * PROPRIETARY/CONFIDENTIAL.  Use of this product is subject to license terms.
 */

package com.sun.portal.search.db;

import com.sun.portal.search.rdm.*;
import com.sun.portal.search.soif.*;
import com.sun.portal.search.util.*;

import java.sql.*;
import javax.naming.*;
import javax.sql.*;

import java.util.*;


/**
 *
 * JDBC search result set implementation using RDMResultSet
 *
 */
public class JDBCResultSet extends RDMResultSet {

  private String statement;
  private List hits;

  int startHit;
  int endHit;
  long hitCount;
  long docCount;
  int resultCount;
    

  /**
   * Creates a new instance of JNDIResultSet
   */
  JDBCResultSet(SToken st, RDMDb database, String query, RDMTransaction t) {
    super(st, database, query, t);
    statement = query;
  }
  

  /**
   * Prepare JDBC Search Results
   */
  void setJDBCSearchResult(ResultSet rs, DatabaseMetaData dmd) throws RDMException {
    startHit = 0;
    endHit = 0;
    hitCount = 0;
    resultCount = 0;
    docCount = 0;
    
    hits = new ArrayList();
    
    ResultSetMetaData rsmd;
    
    try {
      
      if (rs != null) { 
	
	rsmd = rs.getMetaData();
	int numOfColumns = rsmd.getColumnCount();
	
	while (rs.next()) {
	  SOIF s = null;
	  s = new SOIF("DOCUMENT", dmd.getURL()+" "+statement);
	  
	  for (int i=1; i< numOfColumns+1 ; i++) {
	    s.insert(rsmd.getColumnName(i), rs.getString(rsmd.getColumnName(i)));
	  }

	  hits.add(s);
	  
	}
      }
    } catch (Exception e) {
      throw new RDMException(e);
    } 

    int i = hits.size();
    if (i > 0) {
      startHit = 1;
      endHit = i;
      hitCount = i;
      resultCount = i;
      docCount = i;
    }
	
  }
  

  /**
   * Set default attributes
   */
  static Set defaultView = new HashSet();
  static {
    defaultView.add("hl-description");
    defaultView.add("hl-title");
    defaultView.add("url");
    defaultView.add("content-length");
  }


  /**
   * Retrieve Search Results
   * @param i Document index
   * @param view Attributes
   * @param hltags Highlight tags
   * @return a SOIF hit, highlighted and filtered by view
   */
  public SOIF getResult(int i, Set view, String[] hltags) {

    SOIF s = (SOIF)hits.get(i);

    if (view != null && view.contains("score"))
      s.insert("score", "100");	   

    return s;
  }
  
  
  /**
   * Get hit count
   * @return total number of hits for this search
   */
  public long getHitCount() {
    return hitCount;
  }
  
  
  /**
   * Get document count
   * @return number of docs searched
   */
  public long getDocCount() {
    return hits.size();
  }
  
  
  /**
   * Transform the result set to string
   * @return number of docs in this result set
   */
  public java.lang.String toString() {
    return super.toString();
  }
    

  /**
   * Get search result count
   * @return current number of hits in this set
   */
  public int getResultCount() {
    return resultCount;
  }
  
  
}
