/*
 * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
 * PROPRIETARY/CONFIDENTIAL.  Use of this product is subject to license terms.
 */

package com.sun.portal.search.db;

import com.sun.portal.search.rdm.*;
import com.sun.portal.search.soif.*;
import com.sun.portal.search.util.*;

import javax.naming.*;
import javax.naming.directory.*;

import java.util.*;


/**
 *
 * JNDI search result set implementation using RDMResultSet
 *
 */
public class JNDIResultSet extends RDMResultSet {

  private List hits;

  int startHit;
  int endHit;
  long hitCount;
  long docCount;
  int resultCount;


  /** 
   * Creates a new instance of JNDIResultSet 
   */
  JNDIResultSet(SToken st, RDMDb database, String query, RDMTransaction t) {
    super(st, database, query, t);
  }
    

  /**
   * Prepare JNDI Search Results 
   */
  void setJNDISearchResult(NamingEnumeration ne) throws RDMException {
    startHit = 0;
    endHit = 0;
    hitCount = 0;
    resultCount = 0;
    docCount = 0;
	
    hits = new ArrayList();
    try {
      while (ne.hasMoreElements()) {
	Object o = ne.next();
	hits.add(o);
      }
    }
    catch (Exception e) {
      throw new RDMException(e);
    }
    int i = hits.size();
    if (i > 0) {
      startHit = 1;
      endHit = i;
      hitCount = i;
      resultCount = i;
      docCount = i;
    }
    
  }
    
  
  /**
   * Set default attributes 
   */
  static Set defaultView = new HashSet();
  static {
    defaultView.add("hl-description");
    defaultView.add("hl-title");
    defaultView.add("url");
    defaultView.add("content-length");
  }
  

  /**
   * Retrieve Search Results
   * @param i Document index
   * @param view Attributes
   * @param hltags Highlight tags
   * @return a SOIF hit, highlighted and filtered by view
   */
  public SOIF getResult(int i, Set view, String[] hltags) {

    SearchResult sr = (SearchResult)hits.get(i);
    Attributes sra = sr.getAttributes();
    SOIF s = null;

    try {
      s = new SOIF("DOCUMENT", sr.getName());
      NamingEnumeration avs = sra.getAll();
      if (avs != null) {
	while (avs.hasMore()) {
	  Attribute av = (Attribute)avs.next();
	  String name = av.getID();
	  NamingEnumeration n = (NamingEnumeration)av.getAll();
	  int j = 0;
	  while (n.hasMore()) {
	    Object o = n.next();
	    if (o != null && o instanceof String) { 
	      s.insert(name, (String)o, j++);
	    }
	  }
	}
      }	   

      if (view != null && view.contains("score")) {
	s.insert("score", "100");	   
      }
      
    } catch (NamingException ne) {
      //do nothing
    }
    return s;
  }
    

  /**
   * Get hit count
   * @return total number of hits for this search
   */
  public long getHitCount() {
    return hitCount;
  }
    
    
  /**
   * Get document count
   * @return number of docs searched
   */
  public long getDocCount() {
    return hits.size();
  }
    
    
  /**
   * Transform the result set to string
   * @return tring representation of this result set
   */
  public java.lang.String toString() {
    return super.toString();    
  }
    
  
  /**
   * Get search result count
   * @return current number of hits in this set
   */
  public int getResultCount() {
    return resultCount;
  }
      
    
}
